==> TACZ-Refabricated-1.20.1-0.0.3-forge1.1.6-hotfix-sources.jar: com/tacz/guns/init/ModCreativeTabs.java <==
package com.tacz.guns.init;

import com.tacz.guns.GunMod;
import com.tacz.guns.api.DefaultAssets;
import com.tacz.guns.api.item.GunTabType;
import com.tacz.guns.api.item.attachment.AttachmentType;
import com.tacz.guns.api.item.builder.AmmoItemBuilder;
import com.tacz.guns.api.item.builder.AttachmentItemBuilder;
import com.tacz.guns.api.item.builder.GunItemBuilder;
import com.tacz.guns.api.item.gun.AbstractGunItem;
import com.tacz.guns.item.AmmoBoxItem;
import com.tacz.guns.item.AmmoItem;
import com.tacz.guns.item.AttachmentItem;
import com.tacz.guns.item.GunSmithTableItem;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

@SuppressWarnings("all")
public class ModCreativeTabs {
    public static void init() {

    }

    public static class_1761 OTHER_TAB = regiser("other", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("itemGroup.tab.tacz.other"))
            .method_47320(() -> ModItems.GUN_SMITH_TABLE.method_7854())
            .method_47317((parameters, output) -> {
                output.method_45423(GunSmithTableItem.fillItemCategory());
                output.method_45421(ModItems.TARGET);
                output.method_45421(ModItems.STATUE);
                output.method_45421(ModItems.TARGET_MINECART);
                AmmoBoxItem.fillItemCategory(output);
            }).method_47324());

    public static class_1761 AMMO_TAB = regiser("ammo", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("itemGroup.tab.tacz.ammo"))
            .method_47320(() -> AmmoItemBuilder.create().setId(DefaultAssets.DEFAULT_AMMO_ID).build())
            .method_47317((parameters, output) -> output.method_45423(AmmoItem.fillItemCategory())).method_47324());

    public static class_1761 ATTACHMENT_SCOPE_TAB = regiser("scope", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.scope.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "scope_acog_ta31")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.SCOPE))).method_47324());

    public static class_1761 ATTACHMENT_MUZZLE_TAB = regiser("muzzle", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.muzzle.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "muzzle_compensator_trident")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.MUZZLE))).method_47324());

    public static class_1761 ATTACHMENT_STOCK_TAB = regiser("stock", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.stock.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "stock_militech_b5")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.STOCK))).method_47324());

    public static class_1761 ATTACHMENT_GRIP_TAB = regiser("grip", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.grip.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "grip_magpul_afg_2")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.GRIP))).method_47324());

    public static class_1761 ATTACHMENT_EXTENDED_MAG_TAB = regiser("extended_mag", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.extended_mag.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "extended_mag_3")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.EXTENDED_MAG))).method_47324());

    public static class_1761 ATTACHMENT_LASER_TAB = regiser("laser", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.laser.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "laser_compact")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.LASER))).method_47324());

    public static class_1761 GUN_PISTOL_TAB = regiser("pistol", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.pistol.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "glock_17")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.PISTOL))).method_47324());

    public static class_1761 GUN_SNIPER_TAB = regiser("sniper", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.sniper.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "ai_awp")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SNIPER))).method_47324());

    public static class_1761 GUN_RIFLE_TAB = regiser("rifle", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.rifle.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "ak47")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.RIFLE))).method_47324());

    public static class_1761 GUN_SHOTGUN_TAB = regiser("shotgun", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.shotgun.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "db_short")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SHOTGUN))).method_47324());

    public static class_1761 GUN_SMG_TAB = regiser("smg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.smg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "hk_mp5a5")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SMG))).method_47324());

    public static class_1761 GUN_RPG_TAB = regiser("rpg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.rpg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "rpg7")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.RPG))).method_47324());

    public static class_1761 GUN_MG_TAB = regiser("mg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.mg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(new class_2960(GunMod.MOD_ID, "m249")).build())
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.MG))).method_47324());

    private static class_1761 regiser(String name, class_1761 tab) {
        return class_2378.method_10230(class_7923.field_44687, new class_2960(GunMod.MOD_ID, name), tab);
    }
}

==> TACZ-Refabricated-1.21.1-0.0.2-forge1.1.6-hotfix-sources.jar: com/tacz/guns/init/ModCreativeTabs.java <==
package com.tacz.guns.init;

import com.tacz.guns.GunMod;
import com.tacz.guns.api.DefaultAssets;
import com.tacz.guns.api.item.GunTabType;
import com.tacz.guns.api.item.attachment.AttachmentType;
import com.tacz.guns.api.item.builder.AmmoItemBuilder;
import com.tacz.guns.api.item.builder.AttachmentItemBuilder;
import com.tacz.guns.api.item.builder.GunItemBuilder;
import com.tacz.guns.api.item.gun.AbstractGunItem;
import com.tacz.guns.item.AmmoBoxItem;
import com.tacz.guns.item.AmmoItem;
import com.tacz.guns.item.AttachmentItem;
import com.tacz.guns.item.GunSmithTableItem;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5455;
import net.minecraft.class_7923;

@SuppressWarnings("all")
public class ModCreativeTabs {
    public static void init() {

    }

    private static final class_5455 registryAccess= class_5455.method_40302(class_7923.field_41167);

    public static class_1761 OTHER_TAB = regiser("other", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("itemGroup.tab.tacz.other"))
            .method_47320(() -> ModItems.GUN_SMITH_TABLE.method_7854())
            .method_47317((parameters, output) -> {
                output.method_45423(GunSmithTableItem.fillItemCategory());
                output.method_45421(ModItems.TARGET);
                output.method_45421(ModItems.STATUE);
                output.method_45421(ModItems.TARGET_MINECART);
                AmmoBoxItem.fillItemCategory(output);
            }).method_47324());

    public static class_1761 AMMO_TAB = regiser("ammo", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("itemGroup.tab.tacz.ammo"))
            .method_47320(() -> AmmoItemBuilder.create().setId(DefaultAssets.DEFAULT_AMMO_ID).build())
            .method_47317((parameters, output) -> output.method_45423(AmmoItem.fillItemCategory())).method_47324());

    public static class_1761 ATTACHMENT_SCOPE_TAB = regiser("scope", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.scope.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "scope_acog_ta31")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.SCOPE))).method_47324());

    public static class_1761 ATTACHMENT_MUZZLE_TAB = regiser("muzzle", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.muzzle.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "muzzle_compensator_trident")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.MUZZLE))).method_47324());

    public static class_1761 ATTACHMENT_STOCK_TAB = regiser("stock", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.stock.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "stock_militech_b5")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.STOCK))).method_47324());

    public static class_1761 ATTACHMENT_GRIP_TAB = regiser("grip", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.grip.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "grip_magpul_afg_2")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.GRIP))).method_47324());

    public static class_1761 ATTACHMENT_EXTENDED_MAG_TAB = regiser("extended_mag", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.extended_mag.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "extended_mag_3")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.EXTENDED_MAG))).method_47324());

    public static class_1761 ATTACHMENT_LASER_TAB = regiser("laser", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.laser.name"))
            .method_47320(() -> AttachmentItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "laser_compact")).build())
            .method_47317((parameters, output) -> output.method_45423(AttachmentItem.fillItemCategory(AttachmentType.LASER))).method_47324());

    public static class_1761 GUN_PISTOL_TAB = regiser("pistol", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.pistol.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "glock_17")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.PISTOL))).method_47324());

    public static class_1761 GUN_SNIPER_TAB = regiser("sniper", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.sniper.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "ai_awp")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SNIPER))).method_47324());

    public static class_1761 GUN_RIFLE_TAB = regiser("rifle", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.rifle.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "ak47")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.RIFLE))).method_47324());

    public static class_1761 GUN_SHOTGUN_TAB = regiser("shotgun", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.shotgun.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "db_short")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SHOTGUN))).method_47324());

    public static class_1761 GUN_SMG_TAB = regiser("smg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.smg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "hk_mp5a5")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.SMG))).method_47324());

    public static class_1761 GUN_RPG_TAB = regiser("rpg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.rpg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "rpg7")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.RPG))).method_47324());

    public static class_1761 GUN_MG_TAB = regiser("mg", FabricItemGroup.builder()
            .method_47321(class_2561.method_43471("tacz.type.mg.name"))
            .method_47320(() -> GunItemBuilder.create().setId(class_2960.method_60655(GunMod.MOD_ID, "m249")).build(registryAccess))
            .method_47317((parameters, output) -> output.method_45423(AbstractGunItem.fillItemCategory(GunTabType.MG))).method_47324());

    private static class_1761 regiser(String name, class_1761 tab) {
        return class_2378.method_10230(class_7923.field_44687, class_2960.method_60655(GunMod.MOD_ID, name), tab);
    }
}
